/*

    This style sheet has been derived from
    zenlike1.0 by nodethirtythree design
    http://www.nodethirtythree.com

*/

* {
    padding: 0em;
    margin: 0em;
}

body {
    background-color: #08273F;
    /* background: #000000 url('/static/images/bg1.jpg'); */
    padding: 10px 0px 10px 0px;
}

body ,input {
    font-size: 10pt;
    font-family: "georgia", "times new roman", serif;
    color: #333333;
}

p {
    line-height: 1.5em;
    margin-bottom: 1.0em;
    text-align: justify;
}

a {
    color: #B96D00;
    text-decoration: underline;
}

a:hover {
    text-decoration: none;
}

a.anchor {
    color: white;
    text-decoration: none;
    font-weight: bold;
}

a.anchor:hover, a.anchor:active {
    color: #777!important;
}

h3:hover a.anchor,
h4:hover a.anchor,
h5:hover a.anchor,
h6:hover a.anchor {
    color: #777!important;
}

h3 span {
    font-weight: normal;
}

#content h2, #content h3, #content h4 {
    margin-bottom: 0.5em;
}

h3 ,h4 {
    font-weight: bold;
    background-repeat: no-repeat;
    background-position: right;
}

h2, h3 {
    font-size: 1.7em;
}

h4 {
    font-size: 1.2em;
}



.contentarea {
    padding-top: 1.3em;
}

.image {
    border: solid 1px #6F5230;
}

img.left {
    position: relative;
    float: left;
    margin: 0em 1.8em 1.4em 0em;
}

img.right {
    position: relative;
    float: right;
    margin: 0em 0em 1.8em 1.8em;
}

.divider1 {
    position: relative;
    background: #fff url('/static/images/border2.gif') repeat-x;
    height: 14px;
    margin: 2.0em 0em 1.5em 0em;
    clear: both;
}

.divider2 {
    position: relative;
    height: 1px;
    border-bottom: solid 1px #eaeaea;
    margin: 2.0em 0em 2.0em 0em;
}

.post .details {
    position: relative;
    top: -1.5em;
    font-size: 0.8em;
    color: #787878;
}

.post ul.controls {
    clear: both;
}

.post ul.controls li {
    display: inline;
    font-size: 0.8em;
}

.post ul.controls li a {
    background-repeat: no-repeat;
    background-position: left;
    padding: 0em 1.0em 0em 20px;
}

.post ul.controls li a.printerfriendly {
    background-image: url('/static/images/icon-printerfriendly.gif');
}

.post ul.controls li a.comments {
    background-image: url('/static/images/icon-comments.gif');
}

.post ul.controls li a.more {
    background-image: url('/static/images/icon-more.gif');
}

.flashbox {
    background: #FDFCF6 url('/static/images/boxbg.gif') repeat-x;
    left: 0.5em;
    right: 0.5em;
    top: 0.5em;
    padding: 1.5em;
    border-bottom: solid 1px #E1D2BD;
    margin-bottom: 1.5em;
}

.box {
    position: relative;
    background: #FDFCF6 url('/static/images/boxbg.gif') repeat-x;
    left: -1.5em;
    top: -1.5em;
    padding: 1.5em;
    border-bottom: solid 1px #E1D2BD;
    margin-bottom: 1.0em;
}

ul.linklist {
    list-style: none;
}

ul.linklist li {
    line-height: 2.0em;
}

#upbg {
    position: absolute;
    top: 0px;
    left: 0px;
    width: 100%;
    height: 275px;
    /* background: #fff url('/static/images/bg2.jpg') repeat-x; */
    z-index: 1;
}

#outer {
    z-index: 2;
    position: relative;
    /*
        The width value below controls the overall width of the design. By default it's set to 82%
        (so it'll take up 82% of the browser window's width). You can set it to a different percentage
        value (70%, 90%, etc.) or even a pixel value (760px, 800px, etc.) to enforce a fixed width.
    */
    width: 90%;
    border: solid 4px #fff;
    background-color: #fff;
    margin: 0 auto;
}

#header {
    position: relative;
    width: 100%;
    height: 6em;
    background: #2B2B2B url('/static/images/topbg.gif') repeat-x;
    margin-bottom: 2px;
}

#headercontent {
    position: absolute;
    bottom: 0em;
    padding: 0em 2.0em 1.3em 2.0em;
}

#headercontent h1 {
    font-weight: normal;
    color: #fff;
    font-size: 2.5em;
}

#headercontent h1 a {
    text-decoration: none;
    color: inherit;
}

#headercontent h1 sup {
    color: #777;
}

#headercontent h2 {
    font-size: 1.0em;
    font-weight: normal;
    color: #aaa;
}

#pagelogin {
    position: absolute;
    top: 4.7em;
    right: 2.0em;
    padding-right: 0.0em;
    color: #fff;
}

#pagelogin a {
    color: #F2F3DE;
}

#pagelogin input.text {
    margin-right: 0.5em;
    vertical-align: middle;
    border-top: solid 1px #000000;
    border-right: 0px;
    border-bottom: solid 1px #777777;
    border-left: 0px;
    padding: 0.15em;
    width: 10.0em;
}

#pagelogin input.submit {
    background: #939B00 url('/static/images/buttonbg.gif') repeat-x;
    border: solid 1px #5F6800;
    font-weight: bold;
    padding: 0.25em;
    font-size: 0.8em;
    color: #F2F3DE;
    vertical-align: middle;
}

#headerpic {
    position: relative;
    height: 109px;
    background: #fff url('/static/images/hdrpic.jpg') no-repeat top left;
    margin-bottom: 2px;
}

#menu {
    position: relative;
    background: #7F8400 url('/static/images/header_bg_blue.png') repeat-x top left;
    height: 2.8em;
    padding: 0em 1.0em 0em 1.0em;
    margin-bottom: 2px;
}

#menu ul {
    position: absolute;
    top: 0.9em;
}

#menu ul li {
    position: relative;
    display: inline;
}

#menu ul li a {
    padding: 0.5em 1.0em 0.9em 1.0em;
    color: #fff;
    text-decoration: none;
}

#menu ul li a:hover {
    text-decoration: underline;
}

#menu ul li a.active {
    background: #7F8400 url('/static/images/menuactive.gif') repeat-x top left;
}

#menubottom {
    background: #fff url('/static/images/border1.gif') repeat-x;
    height: 14px;
    margin-bottom: 1em;
}

#content {
    padding: 0em 2.0em 1.0em 2.0em;
}

#primarycontainer {
    float: left;
    margin-right: -20.0em;
    width: 100%;
}

#primarycontent {
    margin: 1.5em 22.0em 0em 0em;
}

#secondarycontent {
    margin-top: 1.5em;
    float: right;
    width: 20.0em;
}

.secondarycontent p {
    text-align: left;
}

#footer {
    position: relative;
    height: 2.0em;
    clear: both;
    padding-top: 3.0em;
    background: #fff url('/static/images/border2.gif') repeat-x 0em 0.5em;
    font-size: 0.8em;
}

#footer .left {
    position: absolute;
    left: 2.0em;
    bottom: 1.0em;
}

#footer .right {
    position: absolute;
    right: 2.0em;
    bottom: 0.1em;
}

#footer a {
    text-decoration: none;
}

#paste-container {
    background: #ccc;
}

.paste-header {
    padding: 0.5em 0.5em 0 0.5em;
}

.paste-header h3 {
    background: none;
    margin-bottom: 0.5em;
}

.paste-header .paste-date {
    font-style: italic;
}

.paste-header p {
    margin-bottom: 0.5em;
    font-size: 110%;
}

table.sourcetable {
    width: 100%;
    background: #eee;
    padding: 0;
    border-collapse: collapse;
}

.sourcetable td {
    vertical-align: top;
    padding: 0em;
}

.sourcetable td.linenos {
    text-align: right;
    width: 2.5em;
    padding: 0.3em;
}

.source pre {
    overflow: hidden;
}

.source {
    padding: 0.3em;
    margin: 0;
}


/*
.tableform table tr.odd,
.tableform table tr.even {
    backround-color: #ccc;
}
*/

.tableform table td {
    padding: 0.4em;
}

.fielderror {
    display: block;
    border: solid 1px #f66;
    background-color: #f99;
    /* width: 99%; */
    padding: 0.2em 1em;
    font-weight: bold;
}

#content ol,
#content ul {
    padding: 0 2em 0.5em 2.0em;
}

#styleselect {
    float: left;
    margin-right: 0.5em;
}

#styleselect ul {
    list-style: none;
    margin: 0;
    padding: 0;
}

#styleselect ul li {
    display: inline;
    margin: 0;
    padding: 0 0.3em 0 0;
}

#paste-code {
    clear:both;
}

blockquote {
    margin: 1em 2em;
}

.literal-block {
    margin: 1em;
    padding: 0.5em;
    border: solid 1px #aaa;
    background-color: #eee;
}
