<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
                      "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"
      xmlns:py="http://genshi.edgewall.org/"
      xmlns:xi="http://www.w3.org/2001/XInclude">

<xi:include href="master.html" />
<?python
from turbogears.i18n.format import format_date
def dateandtime(d):
    return format_date(d, format="full", time_format=", %X %Z")
?>

<head>
    <meta content="text/html; charset=UTF-8" http-equiv="content-type" py:replace="''"/>
    <title>Welcome to the SpammCan</title>
</head>
<body>
   <h3>Submit a new paste</h3>
   <div py:replace="form.display(value=values, **params)" id="paste_form" />
</body>
</html>
