<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
                      "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"
      xmlns:py="http://genshi.edgewall.org/"
      xmlns:xi="http://www.w3.org/2001/XInclude"
      py:strip="">

<head py:match="head" py:attrs="select('@*')">
    <meta content="text/html; charset=UTF-8" http-equiv="content-type" py:replace="''"/>
    <title py:replace="''">Your title goes here</title>
    <link py:for="css in tg_css" py:replace="ET(css.display())" />
    <link py:for="js in tg_js_head" py:replace="ET(js.display())" />
    <meta py:replace="select('*')" />
    <link rel="stylesheet" type="text/css" media="screen" href="${tg.url('/static/css/style.css')}" />
</head>

<body py:match="body" py:attrs="select('@*')">

    <div py:for="js in tg_js_bodytop" py:replace="ET(js.display())" />
    <div id="upbg"></div>
    <div id="outer">
        <div id="header">
            <div id="headercontent">
                <h1><a href="${tg.url('/')}">SpammCan</a></h1>
                <h2 py:content="tg.motd" />
            </div>
        </div>

        <div id="menu">
        <!-- HINT: Set the class of any menu link below to "active" to make it appear active -->
            <ul>
                <li><a href="${tg.url('/new')}">New</a></li>
                <li><a href="${tg.url('/mypastes')}">My Pastes</a></li>
                <li><a href="${tg.url('/help')}">Help</a></li>
                <li><a href="${tg.url('/about')}">About</a></li>
            </ul>
        </div>
        <div id="menubottom"></div>

        <div id="content">
            <div id="status_block" class="flashbox"
                py:if="value_of('tg_flash', None)" py:content="tg_flash"></div>
            <div py:replace="select('*|text()')" />
        <!-- global content ends here -->
        </div>

        <div id="footer">
            <div class="left">
                Copyright &copy; 2008 by Christopher Arndt<br/>
                Visit the SpammCan project site at <a
                href="http://chrisarndt.de/project/spammcan/"
                >http://chrisarndt.de/</a>
            </div>
            <div class="right">
                <a href="http://www.turbogears.org/"
                    title="TurboGears ${tg.tg_version} is propelling this web site!"
                    ><img src="${tg.url('/static/images/under_the_hood_blue.png')}"
                    alt="TurboGears under the hood" border="0" /></a>
            </div>
        </div>
    </div> <!-- end outer -->
    <div py:for="js in tg_js_bodybottom" py:replace="ET(js.display())" />

</body>

</html>
